0.1 (2013-04-23)
----------------
- Initial release with code from Yith Library Server
- License change with the agreement of original YLS copyright holders
- Make the scope configurable
- Make the [google,facebook]_callback views return the result of
  a configurable callback function.
